summaryrefslogtreecommitdiff
path: root/qutebrowser/browser/greasemonkey.py
diff options
context:
space:
mode:
Diffstat (limited to 'qutebrowser/browser/greasemonkey.py')
-rw-r--r--qutebrowser/browser/greasemonkey.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/qutebrowser/browser/greasemonkey.py b/qutebrowser/browser/greasemonkey.py
index df8b2b0c2..9e25e49bd 100644
--- a/qutebrowser/browser/greasemonkey.py
+++ b/qutebrowser/browser/greasemonkey.py
@@ -299,7 +299,7 @@ class GreasemonkeyManager(QObject):
"""Add a GreasemonkeyScript to this manager.
Args:
force: Fetch and overwrite any dependancies which are
already locally cached.
"""
if script.requires:
@@ -345,7 +345,7 @@ class GreasemonkeyManager(QObject):
def _add_script_with_requires(self, script, quiet=False):
"""Add a script with pending downloads to this GreasemonkeyManager.
Specifically a script that has dependancies specified via an
`@require` rule.
Args:
@@ -353,7 +353,7 @@ class GreasemonkeyManager(QObject):
quiet: True to suppress the scripts_reloaded signal after
adding `script`.
Returns: True if the script was added, False if there are still
- dependancies being downloaded.
+ dependencies being downloaded.
"""
# See if we are still waiting on any required scripts for this one
for dl in self._in_progress_dls:
@@ -299,7 +299,7 @@ class GreasemonkeyManager(QObject):
"""Add a GreasemonkeyScript to this manager.
Args:
- force: Fetch and overwrite any dependancies which are
+ force: Fetch and overwrite any dependencies which are
already locally cached.
"""
@@ -345,7 +345,7 @@ class GreasemonkeyManager(QObject):
def _add_script_with_requires(self, script, quiet=False):
"""Add a script with pending downloads to this GreasemonkeyManager.
- Specifically a script that has dependancies specified via an
+ Specifically a script that has dependencies specified via an
`@require` rule.
Args: